aboutsummaryrefslogtreecommitdiffstats
path: root/src/imports/controls/qtquickcontrols2plugin.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/imports/controls/qtquickcontrols2plugin.cpp')
-rw-r--r--src/imports/controls/qtquickcontrols2plugin.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/imports/controls/qtquickcontrols2plugin.cpp b/src/imports/controls/qtquickcontrols2plugin.cpp
index 85c51e4f..88fce5ca 100644
--- a/src/imports/controls/qtquickcontrols2plugin.cpp
+++ b/src/imports/controls/qtquickcontrols2plugin.cpp
@@ -122,10 +122,10 @@ void QtQuickControls2Plugin::registerTypes(const char *uri)
createTheme(styleName);
// If the style is Default, we don't need to register the fallback because the Default style
// provides all controls. Also, if we didn't return early here, we can get an infinite import loop
- // when the style is set to Default.
- if (styleName != fallbackStyleName && styleName != QLatin1String("Default")) {
+ // when the style is set to Basic.
+ if (styleName != fallbackStyleName && styleName != QLatin1String("Basic")) {
registeredFallbackStyleUri = ::fallbackStyleUri();
qCDebug(lcQtQuickControlsStylePlugin) << "calling qmlRegisterModuleImport() to register fallback style with"
<< " uri \"" << qtQuickControlsUri << "\" moduleMajor" << QQmlModuleImportModuleAny
@@ -122,10 +122,10 @@ void QtQuickControls2Plugin::registerTypes(const char *uri)
createTheme(styleName);
- // If the style is Default, we don't need to register the fallback because the Default style
+ // If the style is Basic, we don't need to register the fallback because the Basic style
// provides all controls. Also, if we didn't return early here, we can get an infinite import loop